@@ -2,8 +2,8 @@ from rest_framework import viewsets
 
 from vng_api_common.caching import conditional_retrieve
 
-from .models import Hobby, Person
-from .serializers import HobbySerializer, PersonSerializer
+from .models import Group, Hobby, Person
+from .serializers import GroupSerializer, HobbySerializer, PersonSerializer
 
 
 @conditional_retrieve()
@@ -27,3 +27,8 @@ class PersonViewSet(viewsets.ReadOnlyModelViewSet):
 class HobbyViewSet(viewsets.ReadOnlyModelViewSet):
     queryset = Hobby.objects.all()
     serializer_class = HobbySerializer
+
+
+class GroupViewSet(viewsets.ModelViewSet):
+    queryset = Group.objects.all()
+    serializer_class = GroupSerializer
